summaryrefslogtreecommitdiff
path: root/gnu
diff options
context:
space:
mode:
authorAndreas Enge <andreas@enge.fr>2014-11-20 14:01:20 +0100
committerAndreas Enge <andreas@enge.fr>2014-11-20 14:01:20 +0100
commit8c3fc834114306a082d84a83519f870d3c002907 (patch)
treebf4d04ab8d5185c4576ff7772867c6a0caff9040 /gnu
parenta4d891361327a47352429c751198210c0f8fc3b1 (diff)
downloadguix-patches-8c3fc834114306a082d84a83519f870d3c002907.tar
guix-patches-8c3fc834114306a082d84a83519f870d3c002907.tar.gz
gnu: icu4c: Update to 54.1.
* gnu/packages/icu4c.scm (icu4c): Update to 54.1. * gnu/packages/patches/icu4c-test-date-format.patch: Remove unneeded patch. * gnu-system.am (dist_patch_DATA): Unregister dropped patch.
Diffstat (limited to 'gnu')
-rw-r--r--gnu/packages/icu4c.scm7
-rw-r--r--gnu/packages/patches/icu4c-test-date-format.patch17
2 files changed, 3 insertions, 21 deletions
diff --git a/gnu/packages/patches/icu4c-test-date-format.patch b/gnu/packages/patches/icu4c-test-date-format.patch
deleted file mode 100644
index d7f0df98a6..0000000000
--- a/gnu/packages/patches/icu4c-test-date-format.patch
+++ /dev/null
@@ -1,17 +0,0 @@
-Starting with the switch to GCC 4.8.3, we observed this test failure.
-Changing "34" to "134" means that we expect the date to be parsed as
-"2034", not "1934", which seems consistent with the line above.
-
-Reported at <http://bugs.icu-project.org/trac/ticket/10960>.
-
---- icu/source/test/intltest/dtfmttst.cpp 2014-06-16 10:35:46.000000000 +0200
-+++ icu/source/test/intltest/dtfmttst.cpp 2014-06-16 10:35:52.000000000 +0200
-@@ -1129,7 +1129,7 @@ DateFormatTest::TestTwoDigitYear()
- return;
- }
- parse2DigitYear(fmt, "5/6/17", date(117, UCAL_JUNE, 5));
-- parse2DigitYear(fmt, "4/6/34", date(34, UCAL_JUNE, 4));
-+ parse2DigitYear(fmt, "4/6/34", date(134, UCAL_JUNE, 4));
- }
-
- // -------------------------------------
diff --git a/gnu/packages/icu4c.scm b/gnu/packages/icu4c.scm
index 5963fe4276..ea5aecc21f 100644
--- a/gnu/packages/icu4c.scm
+++ b/gnu/packages/icu4c.scm
@@ -28,7 +28,7 @@
(define-public icu4c
(package
(name "icu4c")
- (version "53.1")
+ (version "54.1")
(source (origin
(method url-fetch)
(uri (string-append "http://download.icu-project.org/files/icu4c/"
@@ -37,8 +37,7 @@
(string-map (lambda (x) (if (char=? x #\.) #\_ x)) version)
"-src.tgz"))
(sha256
- (base32 "0a4sg9w054640zncb13lhrcjqn7yg1qilwd1mczc4w60maslz9vg"))
- (patches (list (search-patch "icu4c-test-date-format.patch")))))
+ (base32 "1cwapgjmvrcv1n2wjspj3vahidg596gjfp4jn1gcb4baralcjayl"))))
(build-system gnu-build-system)
(inputs
`(("patchelf" ,patchelf)
@@ -59,7 +58,7 @@
'configure 'patch-configure
(lambda _
;; patch out two occurrences of /bin/sh from configure script
;; that might have disappeared in a release later than 52.1
(substitute* "configure"
(("`/bin/sh")
(string-append "`" (which "bash")))))
@@ -59,7 +58,7 @@
(lambda _
;; patch out two occurrences of /bin/sh from configure script
- ;; that might have disappeared in a release later than 52.1
+ ;; that might have disappeared in a release later than 54.1
(substitute* "configure"
(("`/bin/sh")